@@ -289,11 +289,10 @@ void AuthManager::windowsClosed(const int windowID)
 {
     qDebug() << "Window closed (ID = " << windowID << ").";
 
-    MainWindow *mv = windows[windowID];
+    //MainWindow *mv = windows[windowID];
     windows.remove(windowID);
 
 //    delete(mv);
-    mv = NULL;
 
 //    if (windows.isEmpty() == true && captchaWindows.isEmpty() == true) {
 //        shutdown();
@@ -306,11 +305,10 @@ void AuthManager::captchaWindowsClosed(const int windowID)
 {
     qDebug() << "CaptchaWindow closed (ID = " << windowID << ").";
 
-    CaptchaWindow *mv = captchaWindows[windowID];
+    //CaptchaWindow *mv = captchaWindows[windowID];
     captchaWindows.remove(windowID);
 
 //    delete(mv);
-    mv = NULL;
 
 //    if (windows.isEmpty() == true && captchaWindows.isEmpty() == true ) {
 //        shutdown();
@@ -321,11 +319,10 @@ void AuthManager::authWindowsClosed(const int windowID)
 {
     qDebug() << "AuthWindow closed (ID = " << windowID << ").";
 
-    AuthWindow *mv = loginWindows[windowID];
+    //AuthWindow *mv = loginWindows[windowID];
     loginWindows.remove(windowID);
 
 //    delete(mv);
-    mv = NULL;
 
 //  if (windows.isEmpty() == true && captchaWindows.isEmpty() == true && loginWindows.isEmpty()) {
 //       shutdown();
