@@ -29,7 +29,9 @@
 #include <QUrl>
 
 #include "mainwindow.h"
-
+#include "captchawindow.h"
+#include "authwindow.h"
+#include "authdbusadaptor.h"
 
 class AuthManager : public QObject
 {
@@ -49,10 +51,16 @@ class AuthManager : public QObject
         void auth(const QString &url);
         void auth(const QString &url, const QStringList &params);
         void windowsClosed(const int windowID);
+        void captchaWindowsClosed(const int windowID);
+        void authWindowsClosed(const int windowID);
+        void captcha(const QString &strBase64, const QString clientID);
+        void login(const QString &clientID);
 
     private:
-        int lastWindowsID;
+        int lastWindowsID, lastCaptchaWindowsID, lastLoginWindowsID;
         QHash<int, MainWindow*> windows;
+        QHash<int, CaptchaWindow*> captchaWindows;
+        QHash<int, AuthWindow*> loginWindows;
         AuthDBusAdaptor *adapter;
         QNetworkProxy proxy;
         bool isProxySet;
